@@ -11,9 +11,15 @@
 
 from vrchatapi.model.api_config import APIConfig
 from vrchatapi.model.api_event_config import APIEventConfig
+from vrchatapi.model.api_health import APIHealth
+from vrchatapi.model.add_favorite_request import AddFavoriteRequest
 from vrchatapi.model.avatar import Avatar
 from vrchatapi.model.avatar_id import AvatarID
 from vrchatapi.model.avatar_unity_package_url_object import AvatarUnityPackageUrlObject
+from vrchatapi.model.create_avatar_request import CreateAvatarRequest
+from vrchatapi.model.create_file_request import CreateFileRequest
+from vrchatapi.model.create_file_version_request import CreateFileVersionRequest
+from vrchatapi.model.create_world_request import CreateWorldRequest
 from vrchatapi.model.current_user import CurrentUser
 from vrchatapi.model.deployment_group import DeploymentGroup
 from vrchatapi.model.developer_type import DeveloperType
@@ -30,30 +36,11 @@ from vrchatapi.model.file import File
 from vrchatapi.model.file_data import FileData
 from vrchatapi.model.file_id import FileID
 from vrchatapi.model.file_status import FileStatus
+from vrchatapi.model.file_upload_url import FileUploadURL
 from vrchatapi.model.file_version import FileVersion
+from vrchatapi.model.file_version_upload_status import FileVersionUploadStatus
+from vrchatapi.model.finish_file_data_upload_request import FinishFileDataUploadRequest
 from vrchatapi.model.friend_status import FriendStatus
-from vrchatapi.model.inline_object import InlineObject
-from vrchatapi.model.inline_object1 import InlineObject1
-from vrchatapi.model.inline_object10 import InlineObject10
-from vrchatapi.model.inline_object11 import InlineObject11
-from vrchatapi.model.inline_object12 import InlineObject12
-from vrchatapi.model.inline_object13 import InlineObject13
-from vrchatapi.model.inline_object2 import InlineObject2
-from vrchatapi.model.inline_object3 import InlineObject3
-from vrchatapi.model.inline_object4 import InlineObject4
-from vrchatapi.model.inline_object5 import InlineObject5
-from vrchatapi.model.inline_object6 import InlineObject6
-from vrchatapi.model.inline_object7 import InlineObject7
-from vrchatapi.model.inline_object8 import InlineObject8
-from vrchatapi.model.inline_object9 import InlineObject9
-from vrchatapi.model.inline_response200 import InlineResponse200
-from vrchatapi.model.inline_response2001 import InlineResponse2001
-from vrchatapi.model.inline_response2002 import InlineResponse2002
-from vrchatapi.model.inline_response2003 import InlineResponse2003
-from vrchatapi.model.inline_response2004 import InlineResponse2004
-from vrchatapi.model.inline_response2005 import InlineResponse2005
-from vrchatapi.model.inline_response2006 import InlineResponse2006
-from vrchatapi.model.inline_response400 import InlineResponse400
 from vrchatapi.model.instance import Instance
 from vrchatapi.model.instance_id import InstanceID
 from vrchatapi.model.instance_platforms import InstancePlatforms
@@ -66,6 +53,7 @@ from vrchatapi.model.limited_unity_package import LimitedUnityPackage
 from vrchatapi.model.limited_user import LimitedUser
 from vrchatapi.model.limited_world import LimitedWorld
 from vrchatapi.model.mime_type import MIMEType
+from vrchatapi.model.moderate_user_request import ModerateUserRequest
 from vrchatapi.model.notification import Notification
 from vrchatapi.model.notification_type import NotificationType
 from vrchatapi.model.past_display_name import PastDisplayName
@@ -79,11 +67,20 @@ from vrchatapi.model.release_status import ReleaseStatus
 from vrchatapi.model.response import Response
 from vrchatapi.model.success import Success
 from vrchatapi.model.tag import Tag
+from vrchatapi.model.two_factor_auth_code import TwoFactorAuthCode
 from vrchatapi.model.unity_package import UnityPackage
 from vrchatapi.model.unity_package_id import UnityPackageID
+from vrchatapi.model.update_avatar_request import UpdateAvatarRequest
+from vrchatapi.model.update_favorite_group_request import UpdateFavoriteGroupRequest
+from vrchatapi.model.update_user_request import UpdateUserRequest
+from vrchatapi.model.update_world_request import UpdateWorldRequest
 from vrchatapi.model.user import User
 from vrchatapi.model.user_exists import UserExists
 from vrchatapi.model.user_state import UserState
 from vrchatapi.model.user_status import UserStatus
+from vrchatapi.model.verify2_fa_result import Verify2FAResult
+from vrchatapi.model.verify_auth_token_result import VerifyAuthTokenResult
 from vrchatapi.model.world import World
 from vrchatapi.model.world_id import WorldID
+from vrchatapi.model.world_metadata import WorldMetadata
+from vrchatapi.model.world_publish_status import WorldPublishStatus
